Django Categories v 0.8.2 — Django Categories v0.8.2 documentation

Django Categories v0.8.2 documentation

# Django Categories v 0.8.2

- Table of Contents
- index
  next

# Django Categories v 0.8.2

Contents:

- Getting Started
  - Connecting your model with Django-Categories
- Using categories in templates
  - Getting all items within a category
  - Template Tags
- Registering Models
  - Registering models in settings.py
  - Registering a many-to-one relationship
  - Registering a many-to-many relationship
- Adding the fields to the database
  - Enter South
  - Reconfiguring Fields
- Reference
  - Management Commands
  - Models
  - Settings
  - Template Tags

## Indices and tables

- Index
- Module Index
- Search Page